/*
   Copyright 2011-2012 ALT Linux
   Copyright 2011-2012 Michael Pozhidaev

   This file is part of the Deepsolver.

   Deepsolver is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   Deepsolver is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
*/

#ifndef DEEPSOLVER_H
#define DEEPSOLVER_H

#include"os/system.h"
#include"DefaultValues.h"
#include"logging.h"
#include"DeepsolverExceptions.h"
#include"os/File.h"
#include"os/Directory.h"
#include"utils/StringUtils.h"
#include"DeepsolverTypes.h"
#include"Pkg.h"

#endif //DEEPSOLVER_H
